## ----setup, echo=FALSE--------------------------------------------------------
library(knitr)

options(width=80)

knitr::opts_chunk$set(
    collapse=TRUE,
    comment="")

## ----message=FALSE------------------------------------------------------------
library(gDNAinRNAseqData)

# Retrieving BAM files
bamfiles <- LiYu22subsetBAMfiles()
bamfiles

# Getting information about the gDNA concentrations of each BAM file
pdat <- LiYu22phenoData(bamfiles)
pdat

## ----message=FALSE, warning=FALSE---------------------------------------------
library(gDNAx)

library(TxDb.Hsapiens.UCSC.hg38.knownGene)
txdb <- TxDb.Hsapiens.UCSC.hg38.knownGene

strandM <- identifyStrandMode(bamfiles, txdb, singleEnd=FALSE)
strandM$strandMode

## -----------------------------------------------------------------------------
strandM$Strandedness

## ----message=FALSE------------------------------------------------------------
gdnax <- gDNAdx(bamfiles, txdb, singleEnd=FALSE, strandMode=strandM$strandMode)
gdnax

## -----------------------------------------------------------------------------
dx <- getDx(gdnax)
dx

## ----defdiag, height=10, width=10, out.width="800px", fig.cap="Default diagnostics."----
plot(gdnax, group=pdat$gDNA, pch=19)

## ----alnorigins, height=4, width=8, out.width="800px", fig.cap="Alignment origins."----
plotAlnOrigins(gdnax, group=pdat$gDNA)

## ----frglen, height=4, width=8, out.width="800px", fig.cap="Estimated fragments length distributions."----
plotFrgLength(gdnax)

## -----------------------------------------------------------------------------
igc <- getIgc(gdnax)
head(igc, n=3)

## ----eval=FALSE---------------------------------------------------------------
#  fbf <- filterBAMtxFlag(isSpliceCompatibleJunction=TRUE,
#                          isSpliceCompatibleExonic=TRUE)
#  tmpdir <- tempdir()
#  fstats <- filterBAMtx(gdnax, path=tmpdir, txflag=fbf)
#  # list.files(tmpdir, pattern="*.bam$")
#  fstats

## ----echo=FALSE---------------------------------------------------------------
fstats_f <- file.path(system.file("extdata", package="gDNAx"),
                      "filterBAMtx_fstats.rds")
fstats <- readRDS(fstats_f)
fstats

## ----session_info, cache=FALSE------------------------------------------------
sessionInfo()

